@@ -1,11 +1,11 @@
 from delta_lake.DataLake import DataLake
-
+from delta.tables import DeltaTable
 
 class Bronze(DataLake):
 
-    def __init__(self, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
+    def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                  input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
-        super().__init__(storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
+        super().__init__(spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                  input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin)
         self.initialize_variables()
 
@@ -13,7 +13,7 @@ class Bronze(DataLake):
     def merge(self):
         try:
             if self.table_exist:
-                deltaTable = DeltaTable.forPath(spark, self.mount_data)
+                deltaTable = DeltaTable.forPath(self.spark, self.mount_data)
                 deltaTable.alias(self.target) \
                     .merge(self.events.alias(self.origin), self.string_validate_columns) \
                     .whenMatchedUpdateAll() \
@@ -22,7 +22,7 @@ class Bronze(DataLake):
             else:
                 self.events.write.format("delta").save(self.mount_data)
 
-                spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database,
+                self.spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database,
                                                                                                  self.table_name,
                                                                                                  self.mount_data))
         except Exception as e:
@@ -34,4 +34,4 @@ class Bronze(DataLake):
         self.colums_validate_merge = self.colums_validate_merge_param.split(',')
 
     def load_data(self, input_data):
-        self.events = spark.read.parquet(input_data)
\ No newline at end of file
+        self.events = self.spark.read.parquet(input_data)
\ No newline at end of file
