@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 from notebookutils import mssparkutils
-from delta.tables import *
 from pyspark.sql.functions import *
 import json
 
@@ -13,8 +12,9 @@ class DataLake(ABC):
     json_load_insert_values = {}
     colums_validate_merge = []
 
-    def __init__(self, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
+    def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                  input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
+        self.spark = spark
         self.storage_account_name=storage_account_name
         self.storage_account_access_key=storage_account_access_key
         self.storage_landing = storage_landing
@@ -44,12 +44,12 @@ class DataLake(ABC):
         pass
 
     def initialize_config_storage(self):
-        spark.conf.set(
+        self.spark.conf.set(
             "fs.azure.account.key." + self.storage_account_name + ".blob.core.windows.net",
             self.storage_account_access_key)
 
     def validate_tables(self):
-        list_tables = spark.catalog.listTables(self.database)
+        list_tables = self.spark.catalog.listTables(self.database)
         for item in list_tables:
             print(item)
             print(type(item))
@@ -63,7 +63,7 @@ class DataLake(ABC):
 
 
     def load_data_csv(self, input_data):
-        self.events = spark.read.format("csv").option("header", "true").load(input_data)
+        self.events = self.spark.read.format("csv").option("header", "true").load(input_data)
 
     def create_colums_merge(self):
         string_and = "and"
