@@ -1,11 +1,12 @@
 from delta_lake.DataLake import DataLake
+from delta.tables import DeltaTable
 
 class Silver(DataLake):
     colums_silver_array = []
 
-    def __init__(self, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
+    def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                  input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
-        super().__init__(storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
+        super().__init__(spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
                          input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target,
                          origin)
         self.initialize_variables()
@@ -21,7 +22,7 @@ class Silver(DataLake):
                     .execute()
             else:
                 self.events.write.format("delta").save(self.mount_data)
-                spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database, self.table_name,
+                self.spark.sql("CREATE TABLE IF NOT EXISTS {0}.{1} USING DELTA LOCATION '{2}'".format(self.database, self.table_name,
                                                                                                  self.mount_data))
         except Exception as e:
             print("Error update or create table: " + self.table_name + " explain: " + str(e))
@@ -34,4 +35,4 @@ class Silver(DataLake):
         self.colums_silver_array = self.colums_silver.split(',')
 
     def load_data(self, input_data):
-        self.events = spark.read.format("delta").load("{0}".format(input_data))
\ No newline at end of file
+        self.events = self.spark.read.format("delta").load("{0}".format(input_data))
\ No newline at end of file
